==> transcriptorthology-2.0.6.tar.gz: transcriptorthology-2.0.6/README.md <==

# :dna: Inferring clusters of orthologous and paralogous transcripts

``Algorithm to infer clusters of isoorthologous transcripts using gene-level homology relationships and a Reciprocal Best Hits approach``

![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

<!-- ABOUT THE PROJECT -->
<h2 id="about-the-project"> :pencil: About The Project</h2>


<!-- OVERVIEW -->
<h3 id="overview"> :cloud: Overview</h3>

`A graph-based method to infer isoorthology & recent paralogy relations in a set of homologous transcripts:dna:`

---


<!-- Requirements -->
<h3 id="requirements"> :hammer_and_pick: Requirements</h3>

*   __`python3 (at leat python 3.6)`__
*   __`NetworkX`__
*   __`Pandas`__
*   __`Numpy`__
*   __`ETE toolkit`__


![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

<!-- Package -->
<h3 id="package"> :package: About the package</h3>

``install the package``
<pre><code>pip3 install transcriptorthology</code></pre>

``import package and use the main function``
<pre><code>from transcriptorthology.transcriptOrthology import inferring_transcripts_isoorthology

if __name__ == '__main__':
  gtot_path = './execution/mapping_gene_to_transcripts/ENSGT00390000000080.fasta'
  gt_path = './execution/NHX_trees/ENSGT00390000000080.nwk'
  lower_bound = 0.7
  transcripts_msa_path = './execution/transcripts_alignments/ENSGT00390000000080.alg'
  tsm_conditions = 2
  output_folder = './execution/output_folder'
  
  <span style="color:red;">inferring_transcripts_isoorthology</span>(<span style="color:red;">transcripts_msa_path</span>, <span style="color:green;">gtot_path</span>, <span style="color:purple;">gt_path</span>,<span style="color:orange;">tsm_conditions</span>,<span style="color:yellow;">lower_bound</span>,<span style="color:gray;">output_folder</span>)</code></pre>


![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

---
<br>
<br>
<br>
<br>
<br>
<br>
Copyright © 2023 CoBIUS LAB

==> transcriptorthology-3.0.0.tar.gz: transcriptorthology-3.0.0/README.md <==

# Inferring clusters of orthologous and paralogous transcripts

``Algorithm to infer clusters of isoorthologous transcripts using gene-level homology relationships and a Reciprocal Best Hits approach``

![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

<!-- ABOUT THE PROJECT -->
<h2 id="about-the-project">About The Project</h2>


<!-- OVERVIEW -->
<h3 id="overview">Overview</h3>

`A graph-based method to infer isoorthology & recent paralogy relations in a set of homologous transcripts`

---


<!-- Requirements -->
<h3 id="requirements"> Requirements</h3>

*   __`python3 (at leat python 3.6)`__
*   __`NetworkX`__
*   __`Pandas`__
*   __`Numpy`__
*   __`ETE toolkit`__


![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

<!-- Package -->
<h3 id="package">About the package</h3>

``install the package``
<pre><code>pip3 install transcriptorthology</code></pre>

``import package and use the main function``
<pre><code>from transcriptorthology.transcriptOrthology import inferring_transcripts_isoorthology

if __name__ == '__main__':
  gtot_path = './execution/mapping_gene_to_transcripts/ENSGT00390000000080.fasta'
  gt_path = './execution/NHX_trees/ENSGT00390000000080.nwk'
  lower_bound = 0.7
  transcripts_msa_path = './execution/transcripts_alignments/ENSGT00390000000080.alg'
  tsm_conditions = 2
  output_folder = './execution/output_folder'
  
  <span style="color:red;">inferring_transcripts_isoorthology</span>(<span style="color:red;">transcripts_msa_path</span>, <span style="color:green;">gtot_path</span>, <span style="color:purple;">gt_path</span>,<span style="color:orange;">tsm_conditions</span>,<span style="color:yellow;">lower_bound</span>,<span style="color:gray;">output_folder</span>)</code></pre>


![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)

---
<br>
<br>
<br>
<br>
<br>
<br>
Copyright © 2023 CoBIUS LAB
